@@ -6,6 +6,7 @@ const inputs = $$('.pf-c-form-control');
 export const rowsKey = $('[placeholder="name"]');
 export const rowsValue = $('[placeholder="value"]');
 export const deleteBtn = $$('[data-test-id="pairs-list__delete-btn"]').first();
+export const deleteFromBtn = $('[data-test-id="pairs-list__delete-from-btn"]');
 export const saveBtn = element(by.cssContainingText('.pf-m-primary', 'Save'));
 
 export const prefix = $('[data-test-id=env-prefix]');
@@ -26,13 +27,34 @@ export const addVariable = async (key: string, value: string) => {
   await saveBtn.click();
 };
 
-export const addVariableFrom = async (resourceName: string, resourcePrefix: string) => {
+export const addVariableFrom = async (
+  resourceName: string,
+  resourcePrefix?: string,
+  getExactResource?: boolean,
+) => {
   await isLoaded();
-  await dropDownBtn.first().click();
+  await dropDownBtn
+    .filter(async (elem) => {
+      const elemText = await elem.getText();
+      return elemText === 'Select a resource';
+    })
+    .first()
+    .click();
   await textFilter.sendKeys(resourceName);
-  await option.first().click();
-  await prefix.clear();
-  await prefix.sendKeys(resourcePrefix);
+  if (getExactResource) {
+    await option
+      .filter(async (elem) => {
+        return (await elem.$('.co-resource-item__resource-name').getText()) === resourceName;
+      })
+      .first()
+      .click();
+  } else {
+    await option.first().click();
+  }
+  if (resourcePrefix) {
+    await prefix.clear();
+    await prefix.sendKeys(resourcePrefix);
+  }
   await browser.wait(until.elementToBeClickable(saveBtn), BROWSER_TIMEOUT);
   await saveBtn.click();
 };
@@ -44,3 +66,11 @@ export const deleteVariable = async () => {
   await browser.wait(until.elementToBeClickable(saveBtn), BROWSER_TIMEOUT);
   await saveBtn.click();
 };
+
+export const deleteFromVariable = async () => {
+  await isLoaded();
+  await browser.wait(until.elementToBeClickable(saveBtn), BROWSER_TIMEOUT);
+  await deleteFromBtn.click();
+  await browser.wait(until.elementToBeClickable(saveBtn), BROWSER_TIMEOUT);
+  await saveBtn.click();
+};
