@@ -1,12 +1,12 @@
 import * as _ from 'lodash';
-import { Filter } from '@console/shared';
+import { RowFilter } from '@console/internal/components/filter-toolbar';
 import { getPhase } from './utils';
 
 const allPhases = ['Pending', 'Bound', 'Lost'];
 
-export const obcStatusFilter: Filter = {
+export const obcStatusFilter: RowFilter = {
   type: 'obc-status',
-  selected: allPhases,
+  filterGroupName: 'Status',
   reducer: getPhase,
   items: _.map(allPhases, (phase) => ({
     id: phase,
@@ -17,13 +17,15 @@ export const obcStatusFilter: Filter = {
       return true;
     }
     const phase = getPhase(obc);
-    return phases.selected.has(phase) || !_.includes(phases.all, phase);
+    return (
+      phases.selected.has(phase) || !_.includes(phases.all, phase) || _.isEmpty(phases.selected)
+    );
   },
 };
 
-export const obStatusFilter: Filter = {
+export const obStatusFilter: RowFilter = {
   type: 'ob-status',
-  selected: allPhases,
+  filterGroupName: 'Status',
   reducer: getPhase,
   items: _.map(allPhases, (phase) => ({
     id: phase,
@@ -34,6 +36,8 @@ export const obStatusFilter: Filter = {
       return true;
     }
     const phase = getPhase(ob);
-    return phases.selected.has(phase) || !_.includes(phases.all, phase);
+    return (
+      phases.selected.has(phase) || !_.includes(phases.all, phase) || _.isEmpty(phases.selected)
+    );
   },
 };
